@@ -58,7 +58,6 @@ import javax.security.sasl.RealmCallback;
 import javax.security.sasl.RealmChoiceCallback;
 import javax.security.sasl.SaslException;
 
-import org.jboss.as.cli.ArgumentValueConverter;
 import org.jboss.as.cli.CliConfig;
 import org.jboss.as.cli.CliEvent;
 import org.jboss.as.cli.CliEventListener;
@@ -95,6 +94,7 @@ import org.jboss.as.cli.handlers.PrintWorkingNodeHandler;
 import org.jboss.as.cli.handlers.QuitHandler;
 import org.jboss.as.cli.handlers.ReadAttributeHandler;
 import org.jboss.as.cli.handlers.ReadOperationHandler;
+import org.jboss.as.cli.handlers.EchoDMRHandler;
 import org.jboss.as.cli.handlers.UndeployHandler;
 import org.jboss.as.cli.handlers.VersionHandler;
 import org.jboss.as.cli.handlers.batch.BatchClearHandler;
@@ -125,7 +125,7 @@ import org.jboss.as.cli.operation.OperationCandidatesProvider;
 import org.jboss.as.cli.operation.OperationFormatException;
 import org.jboss.as.cli.operation.OperationRequestAddress;
 import org.jboss.as.cli.operation.ParsedCommandLine;
-import org.jboss.as.cli.operation.PrefixFormatter;
+import org.jboss.as.cli.operation.NodePathFormatter;
 import org.jboss.as.cli.operation.impl.DefaultCallbackHandler;
 import org.jboss.as.cli.operation.impl.DefaultOperationCandidatesProvider;
 import org.jboss.as.cli.operation.impl.DefaultOperationRequestAddress;
@@ -146,9 +146,6 @@ import org.jboss.sasl.util.HexConverter;
  */
 class CommandContextImpl implements CommandContext {
 
-    static final String DEFAULT_CONTROLLER_HOST = "localhost";
-    static final int DEFAULT_CONTROLLER_PORT = 9999;
-
     /** the cli configuration */
     private final CliConfig config;
 
@@ -169,9 +166,9 @@ class CommandContextImpl implements CommandContext {
     /** the controller client */
     private ModelControllerClient client;
     /** the default controller host */
-    private String defaultControllerHost = DEFAULT_CONTROLLER_HOST;
+    private String defaultControllerHost;
     /** the default controller port */
-    private int defaultControllerPort = DEFAULT_CONTROLLER_PORT;
+    private int defaultControllerPort;
     /** the host of the controller */
     private String controllerHost;
     /** the port of the controller */
@@ -189,7 +186,7 @@ class CommandContextImpl implements CommandContext {
     /** operation request address prefix */
     private final OperationRequestAddress prefix = new DefaultOperationRequestAddress();
     /** the prefix formatter */
-    private final PrefixFormatter prefixFormatter = new DefaultPrefixFormatter();
+    private final NodePathFormatter prefixFormatter = new DefaultPrefixFormatter();
     /** provider of operation request candidates for tab-completion */
     private final OperationCandidatesProvider operationCandidatesProvider;
     /** operation request handler */
@@ -225,7 +222,7 @@ class CommandContextImpl implements CommandContext {
     }
 
     CommandContextImpl(String username, char[] password) throws CliInitializationException {
-        this(DEFAULT_CONTROLLER_HOST, DEFAULT_CONTROLLER_PORT, username, password, false);
+        this(null, -1, username, password, false);
     }
 
     /**
@@ -234,26 +231,30 @@ class CommandContextImpl implements CommandContext {
      */
     CommandContextImpl(String defaultControllerHost, int defaultControllerPort, String username, char[] password, boolean initConsole)
             throws CliInitializationException {
+
+        config = CliConfigImpl.load(this);
+
         operationHandler = new OperationRequestHandler();
 
         this.username = username;
         this.password = password;
         if (defaultControllerHost != null) {
             this.defaultControllerHost = defaultControllerHost;
+        } else {
+            this.defaultControllerHost = config.getDefaultControllerHost();
         }
         if (defaultControllerPort != -1) {
             this.defaultControllerPort = defaultControllerPort;
+        } else {
+            this.defaultControllerPort = config.getDefaultControllerPort();
         }
         initCommands();
 
-        config = CliConfigImpl.load(this);
         initSSLContext();
 
         if (initConsole) {
             cmdCompleter = new CommandCompleter(cmdRegistry);
-            this.console = Console.Factory.getConsole(this);
-            console.setUseHistory(true);
-            console.setHistoryFile(new File(SecurityActions.getSystemProperty("user.home"), ".jboss-cli-history"));
+            initBasicConsole();
             console.addCompleter(cmdCompleter);
             this.operationCandidatesProvider = new DefaultOperationCandidatesProvider();
         } else {
@@ -262,11 +263,19 @@ class CommandContextImpl implements CommandContext {
         }
     }
 
+    protected void initBasicConsole() {
+        this.console = Console.Factory.getConsole(this);
+        console.setUseHistory(config.isHistoryEnabled());
+        console.setHistoryFile(new File(config.getHistoryFileDir(), config.getHistoryFileName()));
+        console.getHistory().setMaxSize(config.getHistoryMaxSize());
+    }
+
     private void initCommands() {
         cmdRegistry.registerHandler(new PrefixHandler(), "cd", "cn");
         cmdRegistry.registerHandler(new ClearScreenHandler(), "clear", "cls");
         cmdRegistry.registerHandler(new CommandCommandHandler(cmdRegistry), "command");
         cmdRegistry.registerHandler(new ConnectHandler(), "connect");
+        cmdRegistry.registerHandler(new EchoDMRHandler(), "echo-dmr");
         cmdRegistry.registerHandler(new HelpHandler(), "help", "h");
         cmdRegistry.registerHandler(new HistoryHandler(), "history");
         cmdRegistry.registerHandler(new LsHandler(), "ls");
@@ -320,7 +329,7 @@ class CommandContextImpl implements CommandContext {
 
         // rollout plan
         final GenericTypeOperationHandler rolloutPlan = new GenericTypeOperationHandler(this, "/management-client-content=rollout-plans/rollout-plan", null);
-        rolloutPlan.addValueConverter("content", ArgumentValueConverter.HEADERS);
+        rolloutPlan.addValueConverter("content", new HeadersArgumentValueConverter(this));
         rolloutPlan.addValueCompleter("content", RolloutPlanCompleter.INSTANCE);
         cmdRegistry.registerHandler(rolloutPlan, "rollout-plan");
 
@@ -421,7 +430,7 @@ class CommandContextImpl implements CommandContext {
 
             if (isBatchMode()) {
                 StringBuilder op = new StringBuilder();
-                op.append(getPrefixFormatter().format(parsedCmd.getAddress()));
+                op.append(getNodePathFormatter().format(parsedCmd.getAddress()));
                 op.append(line.substring(line.indexOf(':')));
                 DefaultBatchedCommand batchedCmd = new DefaultBatchedCommand(op.toString(), request);
                 Batch batch = getBatchManager().getActiveBatch();
@@ -488,6 +497,7 @@ class CommandContextImpl implements CommandContext {
     @Override
     public void terminateSession() {
         terminate = true;
+        disconnectController();
     }
 
     @Override
@@ -511,20 +521,14 @@ class CommandContextImpl implements CommandContext {
         }
     }
 
-    @Override
-    public void error(String message, int code) {
-        this.exitCode = code;
+    protected void error(String message) {
+        this.exitCode = 1;
         printLine(message);
     }
 
-    @Override
-    public void error(String message) {
-        error(message, 1);
-    }
-
     private String readLine(String prompt, boolean password, boolean disableHistory) throws IOException {
         if (console == null) {
-            console = Console.Factory.getConsole(this);
+            initBasicConsole();
         }
 
         boolean useHistory = console.isUseHistory();
@@ -589,12 +593,12 @@ class CommandContextImpl implements CommandContext {
     }
 
     @Override
-    public OperationRequestAddress getPrefix() {
+    public OperationRequestAddress getCurrentNodePath() {
         return prefix;
     }
 
     @Override
-    public PrefixFormatter getPrefixFormatter() {
+    public NodePathFormatter getNodePathFormatter() {
 
         return prefixFormatter;
     }
@@ -605,7 +609,12 @@ class CommandContextImpl implements CommandContext {
     }
 
     @Override
-    public void connectController(String host, int port) {
+    public void connectController() throws CommandLineException {
+        connectController(null, -1);
+    }
+
+    @Override
+    public void connectController(String host, int port) throws CommandLineException {
         if (host == null) {
             host = defaultControllerHost;
         }
@@ -627,18 +636,16 @@ class CommandContextImpl implements CommandContext {
                         newClient = tempClient;
                         break;
                     case CONNECTION_FAILURE:
-                        error("The controller is not available at " + host + ":" + port);
-                        break;
+                        throw new CommandLineException("The controller is not available at " + host + ":" + port);
                     case AUTHENTICATION_FAILURE:
-                        error("Unable to authenticate against controller at " + host + ":" + port);
-                        break;
+                        throw new CommandLineException("Unable to authenticate against controller at " + host + ":" + port);
                     case SSL_FAILURE:
                         try {
                             retry = handleSSLFailure();
                         } catch (IOException ignored) {
                         }
                         if (retry == false) {
-                            error("Unable to negotiate SSL connection with controller at " + host + ":" + port);
+                            throw new CommandLineException("Unable to negotiate SSL connection with controller at " + host + ":" + port);
                         }
                         break;
                 }
@@ -656,7 +663,7 @@ class CommandContextImpl implements CommandContext {
                     domainMode = nodeTypes.contains(Util.SERVER_GROUP);
                 }
             } catch (UnknownHostException e) {
-                error("Failed to resolve host '" + host + "': " + e.getLocalizedMessage());
+                throw new CommandLineException("Failed to resolve host '" + host + "': " + e.getLocalizedMessage());
             }
         } while (retry);
     }
@@ -726,11 +733,11 @@ class CommandContextImpl implements CommandContext {
         }
     }
 
-    private static final String[] FINGERPRINT_ALOGRITHMS = new String[] { "MD5", "SHA1" };
+    private static final String[] FINGERPRINT_ALGORITHMS = new String[] { "MD5", "SHA1" };
 
     private Map<String, String> generateFingerprints(final X509Certificate cert) throws IOException  {
-        Map<String, String> fingerprints = new HashMap<String, String>(FINGERPRINT_ALOGRITHMS.length);
-        for (String current : FINGERPRINT_ALOGRITHMS) {
+        Map<String, String> fingerprints = new HashMap<String, String>(FINGERPRINT_ALGORITHMS.length);
+        for (String current : FINGERPRINT_ALGORITHMS) {
             try {
                 fingerprints.put(current, generateFingerPrint(current, cert.getEncoded()));
             } catch (GeneralSecurityException e) {
@@ -944,7 +951,7 @@ class CommandContextImpl implements CommandContext {
             if(!handler.isBatchMode(this)) {
                 throw new OperationFormatException("The command is not allowed in a batch.");
             }
-        } else if (handler instanceof OperationCommand) {
+        } else if (!(handler instanceof OperationCommand)) {
             throw new OperationFormatException("The command does not translate to an operation request.");
         }
 
@@ -1027,8 +1034,6 @@ class CommandContextImpl implements CommandContext {
             printLine("");
         } catch (Throwable t) {
             t.printStackTrace();
-        } finally {
-            disconnectController();
         }
     }
 
