@@ -36,6 +36,7 @@ import org.jboss.as.clustering.GroupMembershipListener;
 import org.jboss.as.clustering.GroupMembershipNotifier;
 import org.jboss.as.clustering.GroupRpcDispatcher;
 import org.jboss.as.clustering.lock.ClusterLockState.State;
+import org.jboss.marshalling.SimpleClassResolver;
 
 import static org.jboss.as.clustering.ClusteringApiLogger.ROOT_LOGGER;
 import static org.jboss.as.clustering.ClusteringApiMessages.MESSAGES;
@@ -136,7 +137,7 @@ public abstract class AbstractClusterLockSupport implements GroupMembershipListe
         long start = System.currentTimeMillis();
         while (left > 0) {
             // Another node we lost to who should take precedence
-            // over ourself in competition for the lock
+            // over ourselves in competition for the lock
             ClusterNode superiorCompetitor = null;
 
             // Only continue if category is unlocked
@@ -247,7 +248,7 @@ public abstract class AbstractClusterLockSupport implements GroupMembershipListe
         this.localHandler.setLocalNode(this.me);
 
         this.rpcTarget = new RpcTarget(this);
-        this.rpcDispatcher.registerRPCHandler(this.serviceHAName, this.rpcTarget, rpcDispatcher.getClass().getClassLoader());
+        this.rpcDispatcher.registerRPCHandler(this.serviceHAName, this.rpcTarget, new SimpleClassResolver(rpcDispatcher.getClass().getClassLoader()));
         this.membershipNotifier.registerGroupMembershipListener(this);
 
         List<ClusterNode> allMembers = new ArrayList<ClusterNode>();
