@@ -213,14 +213,14 @@ public abstract class CommonXml implements XMLElementReader<List<ModelNode>>, XM
 
     protected void writeNamespaces(final XMLExtendedStreamWriter writer, final ModelNode modelNode) throws XMLStreamException {
         final boolean needXsd = modelNode.hasDefined(SCHEMA_LOCATIONS) && modelNode.get(SCHEMA_LOCATIONS).asInt() > 0;
-        final boolean hasNamepaces = modelNode.hasDefined(NAMESPACES);
-        if (!needXsd && !hasNamepaces) {
+        final boolean hasNamespaces = modelNode.hasDefined(NAMESPACES);
+        if (!needXsd && !hasNamespaces) {
             return;
         }
 
         boolean wroteXsd = false;
         final String xsdUri = Namespace.XML_SCHEMA_INSTANCE.getUriString();
-        if (hasNamepaces) {
+        if (hasNamespaces) {
             for (final Property property : modelNode.get(NAMESPACES).asPropertyList()) {
                 final String uri = property.getValue().asString();
                 writer.writeNamespace(property.getName(), uri);
