@@ -123,7 +123,7 @@ public abstract class AbstractOperationTestCase {
             return null;
         }
 
-        public int getRemoteDomainControllertPort() {
+        public int getRemoteDomainControllerPort() {
             return 0;
         }
 
@@ -253,6 +253,8 @@ public abstract class AbstractOperationTestCase {
             return null;
         }
 
+        @Deprecated
+        @SuppressWarnings("deprecation")
         public OperationContext.Type getType() {
             return null;
         }
@@ -299,6 +301,11 @@ public abstract class AbstractOperationTestCase {
             return RESOURCE_REGISTRATION;
         }
 
+        @Override
+        public ImmutableManagementResourceRegistration getRootResourceRegistration() {
+            return null;
+        }
+
         public ServiceRegistry getServiceRegistry(boolean modify) throws UnsupportedOperationException {
             return null;
         }
@@ -363,17 +370,26 @@ public abstract class AbstractOperationTestCase {
         }
 
         public Resource readResource(PathAddress address) {
-            Resource root = this.root;
-            for (PathElement element : operationAddress) {
-                root = root.getChild(element);
-                assertNotNull(root);
-            }
-            if (address == PathAddress.EMPTY_ADDRESS) {
-                return root;
-            }
-            Resource resource = root;
+            return readResource(address, true);
+        }
+
+        @Override
+        public Resource readResource(PathAddress relativeAddress, boolean recursive) {
+            final PathAddress address = operationAddress.append(relativeAddress);
+            return readResourceFromRoot(address);
+        }
+
+        @Override
+        public Resource readResourceFromRoot(PathAddress address) {
+            return readResourceFromRoot(address, true);
+        }
+
+        @Override
+        public Resource readResourceFromRoot(PathAddress address, boolean recursive) {
+            Resource resource = this.root;
             for (PathElement element : address) {
                 resource = resource.getChild(element);
+                assertNotNull(resource);
             }
             return resource;
         }
