@@ -50,6 +50,7 @@ import java.io.ByteArrayInputStream;
 import java.io.Closeable;
 import java.io.File;
 import java.io.FileInputStream;
+import java.io.FileNotFoundException;
 import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
@@ -130,6 +131,7 @@ import org.jboss.as.server.ServerControllerModelUtil;
 import org.jboss.as.server.parsing.StandaloneXml;
 import org.jboss.as.server.services.net.SpecifiedInterfaceAddHandler;
 import org.jboss.as.server.services.security.VaultAddHandler;
+import org.jboss.as.test.shared.FileUtils;
 import org.jboss.dmr.ModelNode;
 import org.jboss.dmr.ModelType;
 import org.jboss.dmr.Property;
@@ -170,6 +172,7 @@ public class ParseAndMarshalModelsTestCase {
 
         JavaArchive archive = ShrinkWrap.create(JavaArchive.class, "bogus.jar");
         archive.addPackage(ParseAndMarshalModelsTestCase.class.getPackage());
+        archive.addClass(FileUtils.class);
         archive.add(new Asset() {
                     public InputStream openStream() {
                         return new ByteArrayInputStream("Dependencies: org.jboss.staxmapper,org.jboss.as.controller,org.jboss.as.deployment-repository,org.jboss.as.server,org.jboss.as.host-controller,org.jboss.as.domain-management,org.jboss.as.security\n\n".getBytes());
@@ -203,27 +206,27 @@ public class ParseAndMarshalModelsTestCase {
 
     @Test
     public void testStandaloneMinimalisticXml() throws Exception {
-        standaloneXmlTest(getExampleConfigFile("standalone-minimalistic.xml"));
+        standaloneXmlTest(getDocsExampleConfigFile("standalone-minimalistic.xml"));
     }
 
     @Test
     public void testStandaloneOSGiOnlyXml() throws Exception {
-        standaloneXmlTest(getExampleConfigFile("standalone-osgi-only.xml"));
+        standaloneXmlTest(getGeneratedExampleConfigFile("standalone-osgi-only.xml"));
     }
 
     @Test
     public void testStandaloneXtsXml() throws Exception {
-        standaloneXmlTest(getExampleConfigFile("standalone-xts.xml"));
+        standaloneXmlTest(getGeneratedExampleConfigFile("standalone-xts.xml"));
     }
 
     @Test
     public void testStandaloneHornetqColocatedXml() throws Exception {
-        standaloneXmlTest(getExampleConfigFile("standalone-hornetq-colocated.xml"));
+        standaloneXmlTest(getGeneratedExampleConfigFile("standalone-hornetq-colocated.xml"));
     }
 
     @Test
     public void testStandaloneJtsXml() throws Exception {
-        standaloneXmlTest(getExampleConfigFile("standalone-jts.xml"));
+        standaloneXmlTest(getGeneratedExampleConfigFile("standalone-jts.xml"));
     }
 
     @Test
@@ -302,7 +305,7 @@ public class ParseAndMarshalModelsTestCase {
         if (file.exists()) {
             file.delete();
         }
-        copyFile(original, file);
+        FileUtils.copyFile(original, file);
         ModelNode originalModel = loadServerModel(file);
         ModelNode reparsedModel = loadServerModel(file);
 
@@ -331,22 +334,23 @@ public class ParseAndMarshalModelsTestCase {
         if (file.exists()) {
             file.delete();
         }
-        copyFile(original, file);
+        FileUtils.copyFile(original, file);
         ModelNode originalModel = loadHostModel(file);
         ModelNode reparsedModel = loadHostModel(file);
 
         compare(originalModel, reparsedModel);
     }
 
-    @Test
-    public void testDomainOSGiOnlyXml() throws Exception {
-        domainXmlTest(getExampleConfigFile("domain-osgi-only.xml"));
-    }
-
-    @Test
-    public void testDomainJtsXml() throws Exception {
-        domainXmlTest(getExampleConfigFile("domain-jts.xml"));
-    }
+    //TODO Leave commented out until domain-osgi-only.xml and domain-jts.xml are definitely removed from the configuration
+//    @Test
+//    public void testDomainOSGiOnlyXml() throws Exception {
+//        domainXmlTest(getExampleConfigFile("domain-osgi-only.xml"));
+//    }
+//
+//    @Test
+//    public void testDomainJtsXml() throws Exception {
+//        domainXmlTest(getExampleConfigFile("domain-jts.xml"));
+//    }
 
     @Test
     public void test700DomainXml() throws Exception {
@@ -384,7 +388,7 @@ public class ParseAndMarshalModelsTestCase {
         if (file.exists()) {
             file.delete();
         }
-        copyFile(original, file);
+        FileUtils.copyFile(original, file);
         ModelNode originalModel = loadDomainModel(file);
         ModelNode reparsedModel = loadDomainModel(file);
 
@@ -642,8 +646,7 @@ public class ParseAndMarshalModelsTestCase {
         final ModelController controller = createController(ProcessType.HOST_CONTROLLER, model, new Setup() {
             public void setup(Resource resource, ManagementResourceRegistration rootRegistration) {
                 DomainModelUtil.updateCoreModel(resource, null);
-                DomainModelUtil.initializeMasterDomainRegistry(rootRegistration, persister, new MockContentRepository(), new MockFileRepository(),
-                        new MockDomainController(), extensionRegistry);
+                DomainModelUtil.initializeMasterDomainRegistry(rootRegistration, persister, new MockContentRepository(), new MockFileRepository(), new MockDomainController(), extensionRegistry);
             }
         });
 
@@ -699,73 +702,33 @@ public class ParseAndMarshalModelsTestCase {
         }
     }
 
-    private File getLegacyConfigFile(String type, final String profile) {
-				File f = new File( System.getProperty("jbossas.ts.submodule.dir") );
-        Assert.assertTrue(f.exists());
-        f = new File(f, "src");
-        Assert.assertTrue("Not found: " + f.getPath(), f.exists());
-        f = new File(f, "test");
-        Assert.assertTrue("Not found: " + f.getPath(), f.exists());
-        f = new File(f, "resources");
-        Assert.assertTrue("Not found: " + f.getPath(), f.exists());
-        f = new File(f, "legacy-configs");
-        Assert.assertTrue("Not found: " + f.getPath(), f.exists());
-        f = new File(f, type);
-        Assert.assertTrue("Not found: " + f.getPath(), f.exists());
-        f = new File(f, profile);
-        Assert.assertTrue("Not found: " + f.getPath(), f.exists());
-        return f;
+    
 
+    
+    //  Get-config methods
+       
+    private File getLegacyConfigFile(String type, String profile) throws FileNotFoundException {
+        return FileUtils.getFileOrCheckParentsIfNotFound(
+                System.getProperty("jbossas.ts.submodule.dir"), 
+                "src/test/resources/legacy-configs/" + type + File.separator + profile
+        );
     }
 
-    private File getExampleConfigFile(String name) {
-        File f = new File( System.getProperty("jbossas.project.dir", "../../..") );
-        f = f.getAbsoluteFile();
-        Assert.assertTrue(f.exists());
-        f = new File(f, "build");
-        Assert.assertTrue("Not found: " + f.getPath(), f.exists());
-        f = new File(f, "src");
-        Assert.assertTrue("Not found: " + f.getPath(), f.exists());
-        f = new File(f, "main");
-        Assert.assertTrue("Not found: " + f.getPath(), f.exists());
-        f = new File(f, "resources");
-        Assert.assertTrue("Not found: " + f.getPath(), f.exists());
-        f = new File(f, "docs");
-        Assert.assertTrue("Not found: " + f.getPath(), f.exists());
-        f = new File(f, "examples");
-        Assert.assertTrue("Not found: " + f.getPath(), f.exists());
-        f = new File(f, "configs");
-        Assert.assertTrue("Not found: " + f.getPath(), f.exists());
-        f = new File(f, name);
-        Assert.assertTrue("Not found: " + f.getPath(), f.exists());
-        return f;
+    private File getDocsExampleConfigFile(String name) throws FileNotFoundException {
+        return FileUtils.getFileOrCheckParentsIfNotFound(
+                System.getProperty("jbossas.project.dir", "../../.."), 
+                "build/src/main/resources/docs/examples/configs" + File.separator + name
+        );
     }
 
-    private void copyFile(final File src, final File dest) throws Exception {
-        final InputStream in = new BufferedInputStream(new FileInputStream(src));
-        try {
-            dest.getParentFile().mkdirs();
-            final OutputStream out = new BufferedOutputStream(new FileOutputStream(dest));
-            try {
-                int i = in.read();
-                while (i != -1) {
-                    out.write(i);
-                    i = in.read();
-                }
-            } finally {
-                close(out);
-            }
-        } finally {
-            close(in);
-        }
+
+    private File getGeneratedExampleConfigFile(String name) throws FileNotFoundException {
+        return FileUtils.getFileOrCheckParentsIfNotFound(
+                System.getProperty("jbossas.project.dir", "../../.."), 
+                "build/target/generated-configs/docs/examples/configs" + File.separator + name
+        );
     }
 
-    private void close(Closeable closeable) {
-        try {
-            closeable.close();
-        } catch (IOException ignore) {
-        }
-    }
 
     DescriptionProvider getRootDescriptionProvider() {
         return new DescriptionProvider() {
